import { PropType } from 'vue';
export interface ISrcObject {
    src?: string;
    srcset?: string;
    lazySrc?: string;
    aspect: number;
}
export declare const makeImageProps: <Defaults extends {
    src?: unknown;
    srcset?: unknown;
    lazySrc?: unknown;
    sizes?: unknown;
    crossorigin?: unknown;
    referrerpolicy?: unknown;
    absolute?: unknown;
    position?: unknown;
    cover?: unknown;
    alt?: unknown;
    color?: unknown;
    eager?: unknown;
    gradient?: unknown;
    draggable?: unknown;
    options?: unknown;
} = {}>(defaults?: Defaults | undefined) => import('../../../utils').AppendDefault<{
    /**
     * URL-адрес изображения.
     */
    src: {
        type: PropType<string | ISrcObject>;
        required: true;
        default: string;
    };
    /**
     * Набор альтернативных изображений для использования в зависимости от размера устройства.
     */
    srcset: {
        type: PropType<string>;
        default: undefined;
    };
    /**
     * Плейсхолдер для показа в ожидании загрузки основного изображения, обычно небольшая миниатюра в base64-кодировке.
     * Применяется фильтр легкого размытия.
     * ВНИМАНИЕ: Этот параметр не имеет эффекта, если не указаны высота и соотношение сторон.
     */
    lazySrc: {
        type: PropType<string>;
        default: undefined;
    };
    /**
     * Для использования srcset.
     */
    sizes: {
        type: PropType<string>;
        default: undefined;
    };
    /**
     * Указывает, что изображения должны быть получены с включенным CORS
     */
    crossorigin: {
        type: PropType<"" | "anonymous" | "use-credentials">;
        default: undefined;
    };
    /**
     * Указывает, какой referrer будет отправлен при получении ресурса
     */
    referrerpolicy: {
        type: PropType<"no-referrer" | "no-referrer-when-downgrade" | "origin" | "origin-when-cross-origin" | "same-origin" | "strict-origin" | "strict-origin-when-cross-origin" | "unsafe-url">;
        default: undefined;
    };
    absolute: {
        type: PropType<boolean>;
        default: boolean;
    };
    /**
     * Применяет стили object-position к изображению и элементам placeholder.
     */
    position: {
        type: PropType<string>;
        default: undefined;
    };
    /**
     * Изменяет размер фонового изображения, чтобы оно занимало весь контейнер.
     */
    cover: {
        type: PropType<boolean>;
        default: boolean;
    };
    /**
     * Альтернативный текст для программ чтения с экрана. Оставьте пустым для декоративных изображений.
     */
    alt: {
        type: PropType<string>;
        default: undefined;
    };
    /**
     * Применяет цвет к фону на котором расположено изображение
     */
    color: {
        type: PropType<string>;
        default: undefined;
    };
    /**
     * Принудительно рендерит контент компонента в DOM, даже если компонент скрыт. Полезно для SEO оптимизации.
     */
    eager: {
        type: PropType<boolean>;
        default: boolean;
    };
    /**
     * Градиент, который нужно применить к изображению. Поддерживает только синтаксис линейного градиента, все остальное должно быть сделано с помощью классов.
     */
    gradient: {
        type: PropType<string>;
        default: undefined;
    };
    /**
     * Управляет поведением изображения при перетаскивании.
     */
    draggable: {
        type: PropType<boolean | "true" | "false">;
        default: undefined;
    };
    /**
     * Параметры, передаваемые Intersection observer.
     */
    options: {
        type: PropType<IntersectionObserverInit>;
        default: () => {
            root: undefined;
            rootMargin: undefined;
            threshold: undefined;
        };
    };
}, Defaults>;
